#line 2 "Gmsh.yy.cpp"

#line 4 "Gmsh.yy.cpp"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer gmsh_yy_create_buffer
#define yy_delete_buffer gmsh_yy_delete_buffer
#define yy_flex_debug gmsh_yy_flex_debug
#define yy_init_buffer gmsh_yy_init_buffer
#define yy_flush_buffer gmsh_yy_flush_buffer
#define yy_load_buffer_state gmsh_yy_load_buffer_state
#define yy_switch_to_buffer gmsh_yy_switch_to_buffer
#define yyin gmsh_yyin
#define yyleng gmsh_yyleng
#define yylex gmsh_yylex
#define yylineno gmsh_yylineno
#define yyout gmsh_yyout
#define yyrestart gmsh_yyrestart
#define yytext gmsh_yytext
#define yywrap gmsh_yywrap
#define yyalloc gmsh_yyalloc
#define yyrealloc gmsh_yyrealloc
#define yyfree gmsh_yyfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE gmsh_yyrestart(gmsh_yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t gmsh_yyleng;

extern FILE *gmsh_yyin, *gmsh_yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up gmsh_yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up gmsh_yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via gmsh_yyrestart()), so that the user can continue scanning by
	 * just pointing gmsh_yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when gmsh_yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t gmsh_yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow gmsh_yywrap()'s to do buffer switches
 * instead of setting up a fresh gmsh_yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void gmsh_yyrestart (FILE *input_file  );
void gmsh_yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE gmsh_yy_create_buffer (FILE *file,int size  );
void gmsh_yy_delete_buffer (YY_BUFFER_STATE b  );
void gmsh_yy_flush_buffer (YY_BUFFER_STATE b  );
void gmsh_yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void gmsh_yypop_buffer_state (void );

static void gmsh_yyensure_buffer_stack (void );
static void gmsh_yy_load_buffer_state (void );
static void gmsh_yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER gmsh_yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE gmsh_yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE gmsh_yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE gmsh_yy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *gmsh_yyalloc (yy_size_t  );
void *gmsh_yyrealloc (void *,yy_size_t  );
void gmsh_yyfree (void *  );

#define yy_new_buffer gmsh_yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        gmsh_yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            gmsh_yy_create_buffer(gmsh_yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        gmsh_yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            gmsh_yy_create_buffer(gmsh_yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *gmsh_yyin = (FILE *) 0, *gmsh_yyout = (FILE *) 0;

typedef int yy_state_type;

extern int gmsh_yylineno;

int gmsh_yylineno = 1;

extern char *gmsh_yytext;
#define yytext_ptr gmsh_yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up gmsh_yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	gmsh_yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 160
#define YY_END_OF_BUFFER 161
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[713] =
    {   0,
        0,    0,  161,  159,    1,    1,  159,    5,  159,    6,
      159,  159,  159,  159,  159,  154,   21,    2,  159,   16,
      159,  158,  158,  158,  158,  158,  158,  158,  158,  158,
      158,  158,  158,  158,  158,  158,  158,  158,  158,  158,
      158,  158,  158,  158,  159,   28,   24,   19,   25,   17,
       26,   18,    0,  156,    3,    4,   20,  155,  154,    0,
       29,   27,   30,  158,  158,  158,  158,  158,  158,  158,
      158,  158,  158,  158,  158,  158,  158,  158,  158,  158,
      158,  158,  158,  158,  158,  158,  158,  158,  158,  158,
      158,  158,  158,  158,  158,  158,  158,   94,   93,  158,

      158,  158,  158,  158,  158,  158,  158,  158,  158,  158,
      158,  112,  158,  158,  158,  158,  158,  158,  158,  158,
      158,  158,  158,  158,  158,  158,  158,  158,  143,  144,
      158,  158,  158,  158,  158,  158,  158,   23,   22,    0,
      155,    0,    0,  157,  158,  158,  158,  158,  158,  158,
      158,  158,  158,  158,  158,  158,  158,  158,  158,  158,
      158,   49,  158,  158,  158,  158,  158,  158,  158,  158,
      158,  158,   65,  158,  158,  158,  158,  158,   78,  158,
      158,  158,  158,  158,  158,  158,  158,  158,  158,  158,
      158,  158,  158,  101,  158,  158,  158,  158,  158,  158,

      158,  158,  158,  158,  158,  158,  158,  158,  158,  158,
      158,  158,  158,  158,  158,  130,  158,  158,  158,  158,
      158,  158,  158,  158,  158,  158,  150,  158,  158,  158,
      158,  158,    0,  156,    0,    0,  155,   31,  158,  158,
      158,  158,   35,   37,  158,  158,  158,   57,  158,   44,
      158,  158,  158,  158,  158,  158,  158,   48,  158,  158,
      158,  158,  158,   64,  158,  158,  158,  158,   73,  158,
       74,  158,  158,   77,  158,  158,  158,  158,  158,   86,
       87,  158,  158,  158,  158,  158,  158,  158,  158,  158,
      158,  158,   99,  158,  100,  158,  158,  158,  158,  158,

      158,  158,  158,  158,  158,  158,  158,  158,  125,  158,
      158,  158,  158,  158,  140,  131,  158,  158,  158,  158,
      129,  158,  158,  158,  158,  158,  158,  145,  149,  158,
      158,  158,  158,   10,   15,    9,    8,  158,   12,   14,
        0,  155,   33,  158,  158,  158,   39,  158,  158,  158,
      158,  158,  158,  158,   52,  158,  158,  158,  158,  158,
      158,  158,  158,  158,  158,  158,   71,  158,  158,   75,
       76,  158,  158,  158,  158,  158,  158,  158,  158,  158,
       92,  158,  158,   97,  158,  158,  158,  102,  158,  158,
      158,  108,  109,  158,  158,  158,  113,  158,  114,  158,

      158,  158,  158,  158,  158,  158,  124,  158,  158,  158,
      134,  158,  158,  158,  158,  158,  158,  158,  151,  158,
      152,  158,   11,  158,   13,  158,   32,   36,   38,  158,
       41,  158,  158,  158,   45,  158,  158,  158,  158,  158,
      158,  158,  158,  158,   61,   63,  158,  158,   70,  158,
      158,  158,  158,  158,   80,  158,  158,   90,   89,  158,
       91,  158,  158,  103,   98,  158,  158,  158,  105,  158,
      158,  158,  118,  158,  117,  158,  158,  158,  127,  123,
      158,  132,  133,  158,  137,  158,  158,  158,  158,  158,
      158,  158,  153,    7,  158,   40,   42,  158,  158,  158,

      158,  158,   47,   51,  158,  158,  158,  158,  158,   67,
      158,  158,  158,   68,  158,  158,  158,  158,  158,  158,
       88,  158,  158,  158,  158,  158,  158,  158,  158,  158,
      158,  158,  158,  158,  158,  136,  158,  158,  135,  158,
      158,  158,  158,  158,  158,  158,  158,  158,  158,  158,
       54,  158,  158,  158,  158,   66,   69,  158,   79,  158,
      158,  158,  158,   82,  158,  158,  104,  106,  107,  158,
      110,  111,  158,  158,  158,  158,  158,  158,  128,  158,
      158,  141,  158,  158,  158,  158,  158,  158,  158,  158,
       46,  158,  158,  158,  158,  158,   72,  158,  158,  158,

       81,  158,   95,  158,  158,  158,  158,  158,  121,  158,
      138,  158,  142,  158,  158,  148,  158,  158,   56,  158,
       53,  158,  158,  158,  158,  158,  158,  158,  158,  115,
      158,  119,  158,  158,  126,  158,  158,  158,  158,   43,
      158,   55,  158,  158,   62,  158,  158,  158,  158,  116,
      120,  158,  139,  158,  146,  158,  158,  158,  158,  158,
      158,  158,  158,  158,  158,  158,  158,  158,  158,  158,
      158,  158,  158,  158,  147,  158,   50,   58,   60,  158,
      158,  158,  158,  122,  158,  158,  158,  158,  158,  158,
       34,  158,  158,  158,  158,  158,  158,  158,  158,  158,

      158,  158,   83,   84,   85,  158,  158,  158,  158,   96,
       59,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    2,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    1,    1,    1,    6,    7,    1,
        1,    8,    9,    1,   10,   11,   12,   13,   14,   15,
       16,   17,   17,   17,   17,   17,   17,   18,   19,   20,
       21,   22,    1,    1,   23,   24,   25,   26,   27,   28,
       29,   30,   31,   32,   33,   34,   35,   36,   37,   38,
       39,   40,   41,   42,   43,   44,   45,   46,   46,   46,
        1,    1,    1,    1,   47,    1,   48,   49,   50,   51,

       52,   53,   54,   55,   56,   46,   57,   58,   59,   60,
       61,   62,   63,   64,   65,   66,   67,   68,   69,   70,
       71,   72,    1,   73,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[74] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    2,    2,    2,    2,    2,    1,    1,    1,
        1,    1,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    1
    } ;

static yyconst flex_int16_t yy_base[714] =
    {   0,
        0,    0,  840,  841,  841,  841,  818,  841,  832,  841,
      816,   65,   66,   64,   76,   78,  841,  841,  815,  814,
      813,   46,   57,   65,   50,   64,   77,   47,   29,   79,
        0,  773,   89,   81,  765,  767,   99,  763,  100,  103,
       92,  764,  767,  775,  753,  841,  841,  841,  841,  841,
      841,  841,  814,  162,  841,  841,  841,  167,  182,  191,
      841,  841,  841,    0,  763,  767,  772,  765,  772,  757,
      746,  750,  106,  760,  767,  750,  157,  761,  132,  754,
      763,  752,  758,  758,  155,  758,  754,  744,  743,  739,
      742,  760,  734,  748,   69,  736,  755,    0,  730,  734,

      723,  142,  733,  159,  761,  740,  726,  738,  724,  723,
      715,    0,  101,   45,  729,  736,  723,  173,  716,  723,
      719,  719,  717,  169,  713,  712,  711,  128,    0,    0,
      739,  713,  721,  723,  714,  711,  699,  841,  841,  227,
      232,  241,  215,  247,  702,  718,  227,  705,  704,  705,
      706,  701,  702,  700,  700,  693,  706,  703,  693,  176,
      689,  697,  703,  694,  697,  696,  699,  677,  689,  115,
      686,  677,    0,  678,  676,  682,  678,  687,    0,  687,
      706,  226,  683,  682,  246,  672,  705,  679,  664,  677,
      674,  675,  674,  711,  662,  676,  655,  672,  668,  671,

      662,  652,  656,  661,  654,  665,  652,  660,  659,  648,
      652,  640,  658,  653,  635,  648,  641,  649,  644,  643,
      632,  240,  644,  637,  645,  667,  638,  644,  631,  630,
      622,  232,  288,  293,  302,  307,  312,    0,  623,  626,
      630,  637,    0,  669,  627,  630,  630,    0,  613,    0,
      631,  620,  613,  612,  619,  215,  623,    0,  607,  612,
      611,  604,  603,    0,  606,  606,  613,  609,    0,  597,
        0,  612,  598,    0,  595,  613,  599,  592,  609,    0,
        0,  589,  603,  606,  601,  586,  611,  586,  584,  584,
      581,  588,    0,  632,    0,  151,  586,  578,  578,  582,

      579,  583,  586,  581,  570,  571,  568,  232,    0,  574,
      572,  567,  564,  578,    0,    0,  562,  563,  206,  566,
        0,  577,  560,  571,  574,  569,  585,    0,    0,  548,
      553,  563,  557,    0,    0,  557,    0,  562,  555,    0,
      317,  322,  567,  546,  550,  549,    0,  548,  543,  550,
      547,  554,  551,  550,  559,  540,  547,  531,  541,  544,
      543,  542,  541,  540,  223,  527,    0,  539,  538,    0,
        0,  532,  257,  519,  522,  527,  518,  523,  522,  518,
        0,  542,  514,    0,  513,  522,  511,    0,  527,  518,
      512,    0,    0,  520,  520,  520,    0,  509,    0,  527,

      514,  502,  516,  512,  503,  510,    0,  506,  508,  507,
        0,  492,  491,  504,  497,  504,  487,  491,    0,  287,
        0,  499,    0,  496,    0,  493,    0,    0,  533,  495,
        0,  486,  487,  478,    0,  483,  494,  489,  470,  479,
      478,  495,  511,  471,    0,    0,  225,  478,    0,  477,
      480,  470,  260,  507,    0,  473,  461,    0,    0,  470,
        0,  489,  473,    0,    0,  472,  463,  450,    0,  455,
      464,  471,    0,  456,    0,  461,  307,  481,    0,    0,
      463,    0,    0,  461,    0,  460,  464,  459,  446,  458,
      303,  460,    0,    0,  441,    0,    0,  452,  465,  452,

      453,  453,    0,    0,  450,  452,  438,  437,  449,    0,
      431,  445,  446,    0,  433,  460,  455,  448,  429,  436,
        0,  453,  436,  419,  427,  431,  418,  431,  422,  424,
      317,  430,  417,  424,  411,    0,  418,  407,    0,  401,
      419,  403,  409,  402,  412,  442,  404,  400,  411,  404,
        0,  395,  398,  399,  392,    0,    0,  397,    0,  419,
      418,  429,  399,    0,  429,  385,    0,    0,    0,  394,
        0,    0,  397,  399,  387,  380,  393,  379,    0,  373,
      386,    0,  383,  392,  383,  386,  400,  375,  376,  378,
        0,  381,  380,  370,  365,  377,    0,  388,  387,  396,

        0,  383,    0,  374,  359,  364,  367,  368,    0,  364,
        0,  350,    0,  366,  350,    0,  353,  344,    0,  348,
        0,  347,  353,  344,  358,  361,  360,  359,  374,    0,
      352,    0,  345,  338,    0,  349,  304,  348,  333,    0,
      332,    0,  336,  348,    0,  351,  350,  349,  355,    0,
        0,  343,    0,  326,    0,  333,  332,  333,  326,  358,
      357,  356,  345,  322,  323,  317,  327,  305,  309,  334,
      333,  332,  324,  304,    0,  307,    0,  328,    0,  321,
      320,  319,  316,    0,  291,  294,  323,  322,  321,  326,
        0,  320,  312,  311,  310,  314,  253,  277,  263,  257,

      252,  177,    0,    0,    0,  168,  121,  144,   51,    0,
        0,  841,   81
    } ;

static yyconst flex_int16_t yy_def[714] =
    {   0,
      712,    1,  712,  712,  712,  712,  712,  712,  712,  712,
      712,  712,  712,  712,  712,  712,  712,  712,  712,  712,
      712,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  712,  712,  712,  712,  712,  712,
      712,  712,  712,  712,  712,  712,  712,  712,  712,  712,
      712,  712,  712,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,

      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  712,  712,  712,
      712,  712,  712,  712,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,

      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  712,  712,  712,  712,  712,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,

      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      712,  712,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,

      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,

      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,

      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,

      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,    0,  712
    } ;

static yyconst flex_int16_t yy_nxt[915] =
    {   0,
        4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
       14,   15,   16,   16,   16,   16,   16,   17,   18,   19,
       20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
       30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
       40,   41,   42,   43,   31,   31,   31,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   44,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       31,   31,   45,   49,   53,   51,   54,   54,   54,   54,
       54,   92,   64,   55,   94,   50,   52,   56,   58,   95,
       59,   59,   59,   59,   59,   65,   57,   70,   93,   96,

      205,   79,  206,   66,   60,   80,  129,  130,   71,   67,
       68,   69,   73,   81,   97,  711,   74,   72,  105,   75,
       76,   82,  131,   83,   86,   77,  184,  185,   78,   60,
       84,   98,   87,   85,   88,   89,  101,   90,   99,  132,
      102,  106,  266,   91,  103,  267,  109,  117,  203,  104,
      110,  118,  133,  111,  112,  134,  113,  121,  122,  114,
      119,  123,  115,  153,  124,  125,  120,  204,  126,  127,
      710,  154,  709,  128,   54,   54,   54,   54,   54,  141,
      141,  141,  141,  141,  164,  165,  224,  225,  140,  166,
      389,  390,   58,  142,   59,   59,   59,   59,   59,  143,

      143,  191,  708,  144,  144,  144,  144,  144,   60,  192,
      172,  158,  194,  140,  159,  160,  173,  161,  142,  195,
      174,  162,  210,  218,  255,  211,  219,  144,  144,  144,
      144,  144,  220,   60,  707,  233,  233,  256,  212,  234,
      234,  234,  234,  234,  141,  141,  141,  141,  141,  236,
      236,  240,  277,  237,  237,  237,  237,  237,  235,  144,
      144,  144,  144,  144,  322,  410,  278,  241,  242,  279,
      282,  411,  357,  402,  283,  358,  510,  323,  706,  324,
      511,  334,  516,  235,  335,  284,  285,  447,  448,  336,
      517,  453,  705,  337,  454,  338,  339,  402,  704,  340,

      234,  234,  234,  234,  234,  234,  234,  234,  234,  234,
      341,  341,  703,  702,  342,  342,  342,  342,  342,  237,
      237,  237,  237,  237,  237,  237,  237,  237,  237,  342,
      342,  342,  342,  342,  342,  342,  342,  342,  342,  491,
      532,  542,  574,  701,  492,  654,  700,  699,  698,  697,
      696,  695,  694,  693,  692,  691,  690,  575,  543,  689,
      688,  687,  533,  686,  532,  542,  685,  574,  684,  654,
      683,  682,  681,  680,  679,  678,  677,  676,  675,  674,
      673,  575,  672,  671,  670,  669,  668,  667,  666,  665,
      664,  663,  662,  661,  660,  659,  658,  657,  656,  655,

      653,  652,  651,  650,  649,  648,  647,  646,  645,  644,
      643,  642,  641,  640,  639,  638,  637,  636,  635,  634,
      633,  632,  631,  630,  629,  628,  627,  626,  625,  624,
      623,  622,  621,  620,  619,  618,  617,  616,  615,  614,
      613,  612,  611,  610,  609,  608,  607,  606,  605,  604,
      603,  602,  601,  600,  599,  598,  597,  596,  595,  594,
      593,  592,  591,  590,  589,  588,  587,  586,  585,  584,
      583,  582,  581,  580,  579,  578,  577,  576,  573,  572,
      571,  570,  569,  568,  567,  566,  565,  564,  563,  562,
      561,  560,  559,  558,  557,  556,  555,  554,  553,  552,

      551,  550,  549,  548,  547,  546,  545,  544,  541,  540,
      539,  538,  537,  536,  535,  534,  531,  530,  529,  528,
      527,  526,  525,  524,  523,  522,  521,  520,  519,  518,
      515,  514,  513,  512,  509,  508,  507,  506,  505,  504,
      503,  502,  501,  500,  499,  498,  497,  496,  495,  494,
      493,  490,  489,  488,  487,  486,  485,  484,  483,  482,
      481,  480,  479,  478,  477,  476,  475,  474,  473,  472,
      471,  470,  469,  468,  467,  466,  465,  464,  463,  462,
      461,  460,  459,  458,  457,  456,  455,  452,  451,  450,
      449,  446,  445,  444,  443,  442,  441,  440,  439,  438,

      437,  436,  435,  434,  433,  432,  431,  430,  429,  428,
      427,  426,  425,  424,  423,  422,  421,  420,  419,  418,
      417,  416,  415,  414,  413,  412,  409,  408,  407,  406,
      405,  404,  403,  401,  400,  399,  398,  397,  396,  395,
      394,  393,  392,  391,  388,  387,  386,  385,  384,  383,
      382,  381,  380,  379,  378,  377,  376,  375,  374,  373,
      372,  371,  370,  369,  368,  367,  366,  365,  364,  363,
      362,  361,  360,  359,  356,  355,  354,  353,  352,  351,
      350,  349,  348,  347,  346,  345,  344,  343,  333,  332,
      331,  330,  329,  328,  327,  326,  325,  321,  320,  319,

      318,  317,  316,  315,  314,  313,  312,  311,  310,  309,
      308,  307,  306,  305,  304,  303,  302,  301,  300,  299,
      298,  297,  296,  295,  294,  293,  292,  291,  290,  289,
      288,  287,  286,  281,  280,  276,  275,  274,  273,  272,
      271,  270,  269,  268,  265,  264,  263,  262,  261,  260,
      259,  258,  257,  254,  253,  252,  251,  250,  249,  248,
      247,  246,  245,  244,  243,  239,  238,  232,  231,  230,
      229,  228,  227,  226,  223,  222,  221,  217,  216,  215,
      214,  213,  209,  208,  207,  202,  201,  200,  199,  198,
      197,  196,  193,  190,  189,  188,  187,  186,  183,  182,

      181,  180,  179,  178,  177,  176,  175,  171,  170,  169,
      168,  167,  163,  157,  156,  155,  152,  151,  150,  149,
      148,  147,  146,  145,  139,  138,  137,  136,  135,  116,
      108,  107,  100,   63,   62,   61,   48,   47,   46,  712,
        3,  712,  712,  712,  712,  712,  712,  712,  712,  712,
      712,  712,  712,  712,  712,  712,  712,  712,  712,  712,
      712,  712,  712,  712,  712,  712,  712,  712,  712,  712,
      712,  712,  712,  712,  712,  712,  712,  712,  712,  712,
      712,  712,  712,  712,  712,  712,  712,  712,  712,  712,
      712,  712,  712,  712,  712,  712,  712,  712,  712,  712,

      712,  712,  712,  712,  712,  712,  712,  712,  712,  712,
      712,  712,  712,  712
    } ;

static yyconst flex_int16_t yy_chk[915] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,   12,   14,   13,   14,   14,   14,   14,
       14,   28,  713,   15,   29,   12,   13,   15,   16,   29,
       16,   16,   16,   16,   16,   22,   15,   23,   28,   29,

      114,   25,  114,   22,   16,   25,   41,   41,   23,   22,
       22,   22,   24,   25,   30,  709,   24,   23,   34,   24,
       24,   26,   41,   26,   27,   24,   95,   95,   24,   16,
       26,   30,   27,   26,   27,   27,   33,   27,   30,   41,
       33,   34,  170,   27,   33,  170,   37,   39,  113,   33,
       37,   39,   41,   37,   37,   41,   37,   40,   40,   37,
       39,   40,   37,   73,   40,   40,   39,  113,   40,   40,
      708,   73,  707,   40,   54,   54,   54,   54,   54,   58,
       58,   58,   58,   58,   79,   79,  128,  128,   54,   79,
      296,  296,   59,   58,   59,   59,   59,   59,   59,   60,

       60,  102,  706,   60,   60,   60,   60,   60,   59,  102,
       85,   77,  104,   54,   77,   77,   85,   77,   58,  104,
       85,   77,  118,  124,  160,  118,  124,  143,  143,  143,
      143,  143,  124,   59,  702,  140,  140,  160,  118,  140,
      140,  140,  140,  140,  141,  141,  141,  141,  141,  142,
      142,  147,  182,  142,  142,  142,  142,  142,  141,  144,
      144,  144,  144,  144,  222,  319,  182,  147,  147,  182,
      185,  319,  256,  308,  185,  256,  447,  222,  701,  222,
      447,  232,  453,  141,  232,  185,  185,  365,  365,  232,
      453,  373,  700,  232,  373,  232,  232,  308,  699,  232,

      233,  233,  233,  233,  233,  234,  234,  234,  234,  234,
      235,  235,  698,  697,  235,  235,  235,  235,  235,  236,
      236,  236,  236,  236,  237,  237,  237,  237,  237,  341,
      341,  341,  341,  341,  342,  342,  342,  342,  342,  420,
      477,  491,  531,  696,  420,  637,  695,  694,  693,  692,
      690,  689,  688,  687,  686,  685,  683,  531,  491,  682,
      681,  680,  477,  678,  477,  491,  676,  531,  674,  637,
      673,  672,  671,  670,  669,  668,  667,  666,  665,  664,
      663,  531,  662,  661,  660,  659,  658,  657,  656,  654,
      652,  649,  648,  647,  646,  644,  643,  641,  639,  638,

      636,  634,  633,  631,  629,  628,  627,  626,  625,  624,
      623,  622,  620,  618,  617,  615,  614,  612,  610,  608,
      607,  606,  605,  604,  602,  600,  599,  598,  596,  595,
      594,  593,  592,  590,  589,  588,  587,  586,  585,  584,
      583,  581,  580,  578,  577,  576,  575,  574,  573,  570,
      566,  565,  563,  562,  561,  560,  558,  555,  554,  553,
      552,  550,  549,  548,  547,  546,  545,  544,  543,  542,
      541,  540,  538,  537,  535,  534,  533,  532,  530,  529,
      528,  527,  526,  525,  524,  523,  522,  520,  519,  518,
      517,  516,  515,  513,  512,  511,  509,  508,  507,  506,

      505,  502,  501,  500,  499,  498,  495,  492,  490,  489,
      488,  487,  486,  484,  481,  478,  476,  474,  472,  471,
      470,  468,  467,  466,  463,  462,  460,  457,  456,  454,
      452,  451,  450,  448,  444,  443,  442,  441,  440,  439,
      438,  437,  436,  434,  433,  432,  430,  429,  426,  424,
      422,  418,  417,  416,  415,  414,  413,  412,  410,  409,
      408,  406,  405,  404,  403,  402,  401,  400,  398,  396,
      395,  394,  391,  390,  389,  387,  386,  385,  383,  382,
      380,  379,  378,  377,  376,  375,  374,  372,  369,  368,
      366,  364,  363,  362,  361,  360,  359,  358,  357,  356,

      355,  354,  353,  352,  351,  350,  349,  348,  346,  345,
      344,  343,  339,  338,  336,  333,  332,  331,  330,  327,
      326,  325,  324,  323,  322,  320,  318,  317,  314,  313,
      312,  311,  310,  307,  306,  305,  304,  303,  302,  301,
      300,  299,  298,  297,  294,  292,  291,  290,  289,  288,
      287,  286,  285,  284,  283,  282,  279,  278,  277,  276,
      275,  273,  272,  270,  268,  267,  266,  265,  263,  262,
      261,  260,  259,  257,  255,  254,  253,  252,  251,  249,
      247,  246,  245,  244,  242,  241,  240,  239,  231,  230,
      229,  228,  227,  226,  225,  224,  223,  221,  220,  219,

      218,  217,  216,  215,  214,  213,  212,  211,  210,  209,
      208,  207,  206,  205,  204,  203,  202,  201,  200,  199,
      198,  197,  196,  195,  194,  193,  192,  191,  190,  189,
      188,  187,  186,  184,  183,  181,  180,  178,  177,  176,
      175,  174,  172,  171,  169,  168,  167,  166,  165,  164,
      163,  162,  161,  159,  158,  157,  156,  155,  154,  153,
      152,  151,  150,  149,  148,  146,  145,  137,  136,  135,
      134,  133,  132,  131,  127,  126,  125,  123,  122,  121,
      120,  119,  117,  116,  115,  111,  110,  109,  108,  107,
      106,  105,  103,  101,  100,   99,   97,   96,   94,   93,

       92,   91,   90,   89,   88,   87,   86,   84,   83,   82,
       81,   80,   78,   76,   75,   74,   72,   71,   70,   69,
       68,   67,   66,   65,   53,   45,   44,   43,   42,   38,
       36,   35,   32,   21,   20,   19,   11,    9,    7,    3,
      712,  712,  712,  712,  712,  712,  712,  712,  712,  712,
      712,  712,  712,  712,  712,  712,  712,  712,  712,  712,
      712,  712,  712,  712,  712,  712,  712,  712,  712,  712,
      712,  712,  712,  712,  712,  712,  712,  712,  712,  712,
      712,  712,  712,  712,  712,  712,  712,  712,  712,  712,
      712,  712,  712,  712,  712,  712,  712,  712,  712,  712,

      712,  712,  712,  712,  712,  712,  712,  712,  712,  712,
      712,  712,  712,  712
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int gmsh_yy_flex_debug;
int gmsh_yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *gmsh_yytext;
#line 1 "Gmsh.l"
#line 2 "Gmsh.l"
// Gmsh - Copyright (C) 1997-2011 C. Geuzaine, J.-F. Remacle
//
// See the LICENSE.txt file for license information. Please report all
// bugs and problems to <gmsh@geuz.org>.

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include "GmshMessage.h"
#include "Geo.h"
#include "Gmsh.tab.hpp"

void   parsestring(char endchar);
char  *strsave(char *ptr);
void   skipcomments(void);
void   skipline(void);

#define YY_INPUT(buf,result,max_size)					\
     {									\
       int c = '*', n;							\
       for ( n = 0; n < max_size &&					\
	       (c = getc( gmsh_yyin )) != EOF && c != '\n'; ++n )		\
	 buf[n] = (char) c;						\
       if ( c == '\n' ){						\
	 buf[n++] = (char) c;						\
	 gmsh_yylineno++;							\
       }								\
       if ( c == EOF && ferror( gmsh_yyin ) )				\
	 Msg::Fatal("Input in flex scanner failed");			\
       result = n;							\
     }									\

#if defined(WIN32)
#define isatty(arg) -1
#define YY_NO_UNISTD_H
#endif

#line 949 "Gmsh.yy.cpp"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int gmsh_yylex_destroy (void );

int gmsh_yyget_debug (void );

void gmsh_yyset_debug (int debug_flag  );

YY_EXTRA_TYPE gmsh_yyget_extra (void );

void gmsh_yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *gmsh_yyget_in (void );

void gmsh_yyset_in  (FILE * in_str  );

FILE *gmsh_yyget_out (void );

void gmsh_yyset_out  (FILE * out_str  );

yy_size_t gmsh_yyget_leng (void );

char *gmsh_yyget_text (void );

int gmsh_yyget_lineno (void );

void gmsh_yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int gmsh_yywrap (void );
#else
extern int gmsh_yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( gmsh_yytext, gmsh_yyleng, 1, gmsh_yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		yy_size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( gmsh_yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( gmsh_yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, gmsh_yyin))==0 && ferror(gmsh_yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(gmsh_yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int gmsh_yylex (void);

#define YY_DECL int gmsh_yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after gmsh_yytext and gmsh_yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 49 "Gmsh.l"


#line 1134 "Gmsh.yy.cpp"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! gmsh_yyin )
			gmsh_yyin = stdin;

		if ( ! gmsh_yyout )
			gmsh_yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			gmsh_yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				gmsh_yy_create_buffer(gmsh_yyin,YY_BUF_SIZE );
		}

		gmsh_yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of gmsh_yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 713 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 841 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 51 "Gmsh.l"
/* none */;
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 52 "Gmsh.l"
return tEND;
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 53 "Gmsh.l"
skipcomments();
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 54 "Gmsh.l"
skipline();
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 55 "Gmsh.l"
{ parsestring('\"'); return tBIGSTR; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 56 "Gmsh.l"
{ parsestring('\''); return tBIGSTR; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 57 "Gmsh.l"
{ gmsh_yylval.d = NEWREG(); return tDOUBLE; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 58 "Gmsh.l"
{ gmsh_yylval.d = NEWPOINT(); return tDOUBLE; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 59 "Gmsh.l"
{ gmsh_yylval.d = NEWLINE(); return tDOUBLE; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 60 "Gmsh.l"
{ gmsh_yylval.d = NEWLINE(); return tDOUBLE; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 61 "Gmsh.l"
{ gmsh_yylval.d = NEWLINELOOP(); return tDOUBLE; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 62 "Gmsh.l"
{ gmsh_yylval.d = NEWSURFACE(); return tDOUBLE; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 63 "Gmsh.l"
{ gmsh_yylval.d = NEWSURFACELOOP(); return tDOUBLE; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 64 "Gmsh.l"
{ gmsh_yylval.d = NEWVOLUME(); return tDOUBLE; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 65 "Gmsh.l"
{ gmsh_yylval.d = NEWFIELD(); return tDOUBLE; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 66 "Gmsh.l"
return tAFFECT;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 67 "Gmsh.l"
return tAFFECTPLUS;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 68 "Gmsh.l"
return tAFFECTMINUS;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 69 "Gmsh.l"
return tAFFECTTIMES;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 70 "Gmsh.l"
return tAFFECTDIVIDE;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 71 "Gmsh.l"
return tDOTS;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 72 "Gmsh.l"
return tDOTS;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 73 "Gmsh.l"
return tOR;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 74 "Gmsh.l"
return tAND;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 75 "Gmsh.l"
return tPLUSPLUS;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 76 "Gmsh.l"
return tMINUSMINUS;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 77 "Gmsh.l"
return tEQUAL;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 78 "Gmsh.l"
return tNOTEQUAL;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 79 "Gmsh.l"
return tLESSOREQUAL;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 80 "Gmsh.l"
return tGREATEROREQUAL;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 82 "Gmsh.l"
return tAcos;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 83 "Gmsh.l"
return tAcos;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 84 "Gmsh.l"
return tAlias;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 85 "Gmsh.l"
return tAliasWithOptions;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 86 "Gmsh.l"
return tAsin;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 87 "Gmsh.l"
return tAsin;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 88 "Gmsh.l"
return tAtan;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 89 "Gmsh.l"
return tAtan;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 90 "Gmsh.l"
return tAtan2;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 91 "Gmsh.l"
return tAtan2;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 93 "Gmsh.l"
return tBezier;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 94 "Gmsh.l"
return tBSpline;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 95 "Gmsh.l"
return tBoundingBox;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 97 "Gmsh.l"
return tCeil;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 98 "Gmsh.l"
return tCircle;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 99 "Gmsh.l"
return tCoherence;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 100 "Gmsh.l"
return tCombine;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 101 "Gmsh.l"
return tCosh;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 102 "Gmsh.l"
return tCos;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 103 "Gmsh.l"
return tCharacteristic;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 104 "Gmsh.l"
return tComplex;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 105 "Gmsh.l"
return tColor;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 106 "Gmsh.l"
return tColorTable;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 107 "Gmsh.l"
return tCompound;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 108 "Gmsh.l"
return tCoordinates;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 109 "Gmsh.l"
return tSpline;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 110 "Gmsh.l"
return tCall;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 111 "Gmsh.l"
return tCreateTopology;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 112 "Gmsh.l"
return tCreateTopologyNoHoles;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 114 "Gmsh.l"
return tDefineConstant;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 115 "Gmsh.l"
return tDelete;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 116 "Gmsh.l"
return tDegenerated;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 117 "Gmsh.l"
return tDilate;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 118 "Gmsh.l"
return tDraw;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 120 "Gmsh.l"
return tExp;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 121 "Gmsh.l"
return tEllipse;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 122 "Gmsh.l"
return tEllipse;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 123 "Gmsh.l"
return tExtrude;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 124 "Gmsh.l"
return tElliptic;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 125 "Gmsh.l"
return tEndFor;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 126 "Gmsh.l"
return tEndIf;
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 127 "Gmsh.l"
return tEuclidian;
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 128 "Gmsh.l"
return tExit;
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 130 "Gmsh.l"
return tFabs;
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 131 "Gmsh.l"
return tField;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 132 "Gmsh.l"
return tFloor;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 133 "Gmsh.l"
return tFmod;
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 134 "Gmsh.l"
return tFor;
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 135 "Gmsh.l"
return tFunction;
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 137 "Gmsh.l"
return tGetEnv;
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 138 "Gmsh.l"
return tGetString;
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 139 "Gmsh.l"
return tGetValue;
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 140 "Gmsh.l"
return tGMSH_MAJOR_VERSION;
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 141 "Gmsh.l"
return tGMSH_MINOR_VERSION;
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 142 "Gmsh.l"
return tGMSH_PATCH_VERSION;
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 144 "Gmsh.l"
return tHide;
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 145 "Gmsh.l"
return tHole;
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 146 "Gmsh.l"
return tHomRank;
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 147 "Gmsh.l"
return tHomGen;
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 148 "Gmsh.l"
return tHomCut;
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 149 "Gmsh.l"
return tHomSeq;
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 150 "Gmsh.l"
return tHypot;
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 152 "Gmsh.l"
return tIn;
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 153 "Gmsh.l"
return tIf;
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 154 "Gmsh.l"
return tIntersect;
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 155 "Gmsh.l"
return tInterpolationScheme;
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 157 "Gmsh.l"
return tNurbsKnots;
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 159 "Gmsh.l"
return tLength;
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 160 "Gmsh.l"
return tLine;
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 161 "Gmsh.l"
return tLoop;
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 162 "Gmsh.l"
return tLog;
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 163 "Gmsh.l"
return tLog10;
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 164 "Gmsh.l"
return tLayers;
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 165 "Gmsh.l"
return tLevelset;
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 167 "Gmsh.l"
return tModulo;
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 168 "Gmsh.l"
return tMPI_Rank;
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 169 "Gmsh.l"
return tMPI_Size;
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 171 "Gmsh.l"
return tNurbs;
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 173 "Gmsh.l"
return tNurbsOrder;
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 175 "Gmsh.l"
return tPeriodic;
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 176 "Gmsh.l"
return tPhysical;
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 177 "Gmsh.l"
return tPi;
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 178 "Gmsh.l"
return tPlane;
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 179 "Gmsh.l"
return tPoint;
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 180 "Gmsh.l"
return tParametric;
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 181 "Gmsh.l"
return tPolarSphere;
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 182 "Gmsh.l"
return tPrintf;
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 183 "Gmsh.l"
return tPlugin;
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 185 "Gmsh.l"
return tQuadTriDbl;
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 186 "Gmsh.l"
return tQuadTriSngl;
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 188 "Gmsh.l"
return tRecombine;
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 189 "Gmsh.l"
return tRecombLaterals;
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 190 "Gmsh.l"
return tRotate;
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 191 "Gmsh.l"
return tRuled;
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 192 "Gmsh.l"
return tRand;
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 193 "Gmsh.l"
return tRefineMesh;
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 194 "Gmsh.l"
return tReturn;
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 196 "Gmsh.l"
return tSmoother;
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 197 "Gmsh.l"
return tSqrt;
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 198 "Gmsh.l"
return tSin;
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 199 "Gmsh.l"
return tSinh;
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 200 "Gmsh.l"
return tSphere;
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 201 "Gmsh.l"
return tSpline;
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 202 "Gmsh.l"
return tSplit;
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 203 "Gmsh.l"
return tSurface;
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 204 "Gmsh.l"
return tSprintf;
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 205 "Gmsh.l"
return tStrCat;
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 206 "Gmsh.l"
return tStrPrefix;
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 207 "Gmsh.l"
return tStrRelative;
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 208 "Gmsh.l"
return tShow;
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 209 "Gmsh.l"
return tSymmetry;
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 210 "Gmsh.l"
return tSyncModel;
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 212 "Gmsh.l"
return tText2D;
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 213 "Gmsh.l"
return tText3D;
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 214 "Gmsh.l"
return tTime;
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 215 "Gmsh.l"
return tTransfinite;
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 216 "Gmsh.l"
return tTransfQuadTri;
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 217 "Gmsh.l"
return tTranslate;
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 218 "Gmsh.l"
return tTanh;
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 219 "Gmsh.l"
return tTan;
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 220 "Gmsh.l"
return tToday;
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 222 "Gmsh.l"
return tUsing;
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 224 "Gmsh.l"
return tVolume;
	YY_BREAK
case 154:
#line 227 "Gmsh.l"
case 155:
#line 228 "Gmsh.l"
case 156:
#line 229 "Gmsh.l"
case 157:
YY_RULE_SETUP
#line 229 "Gmsh.l"
{ gmsh_yylval.d = atof((char *)gmsh_yytext); return tDOUBLE; }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 231 "Gmsh.l"
{ gmsh_yylval.c = strsave((char*)gmsh_yytext); return tSTRING; }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 233 "Gmsh.l"
return gmsh_yytext[0];
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 235 "Gmsh.l"
ECHO;
	YY_BREAK
#line 2009 "Gmsh.yy.cpp"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed gmsh_yyin at a new source and called
			 * gmsh_yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = gmsh_yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( gmsh_yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * gmsh_yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of gmsh_yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					gmsh_yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			gmsh_yyrestart(gmsh_yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) gmsh_yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 713 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 713 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 712);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up gmsh_yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					gmsh_yyrestart(gmsh_yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( gmsh_yywrap( ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve gmsh_yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void gmsh_yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        gmsh_yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            gmsh_yy_create_buffer(gmsh_yyin,YY_BUF_SIZE );
	}

	gmsh_yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	gmsh_yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void gmsh_yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		gmsh_yypop_buffer_state();
	 *		gmsh_yypush_buffer_state(new_buffer);
     */
	gmsh_yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	gmsh_yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (gmsh_yywrap()) processing, but the only time this flag
	 * is looked at is after gmsh_yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void gmsh_yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	gmsh_yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE gmsh_yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) gmsh_yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in gmsh_yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) gmsh_yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in gmsh_yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	gmsh_yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with gmsh_yy_create_buffer()
 * 
 */
    void gmsh_yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		gmsh_yyfree((void *) b->yy_ch_buf  );

	gmsh_yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a gmsh_yyrestart() or at EOF.
 */
    static void gmsh_yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	gmsh_yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then gmsh_yy_init_buffer was _probably_
     * called from gmsh_yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void gmsh_yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		gmsh_yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void gmsh_yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	gmsh_yyensure_buffer_stack();

	/* This block is copied from gmsh_yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from gmsh_yy_switch_to_buffer. */
	gmsh_yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void gmsh_yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	gmsh_yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		gmsh_yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void gmsh_yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)gmsh_yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in gmsh_yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)gmsh_yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in gmsh_yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE gmsh_yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) gmsh_yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in gmsh_yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	gmsh_yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to gmsh_yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       gmsh_yy_scan_bytes() instead.
 */
YY_BUFFER_STATE gmsh_yy_scan_string (yyconst char * yystr )
{
    
	return gmsh_yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to gmsh_yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE gmsh_yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n, i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) gmsh_yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in gmsh_yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = gmsh_yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in gmsh_yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up gmsh_yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		gmsh_yytext[gmsh_yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = gmsh_yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		gmsh_yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int gmsh_yyget_lineno  (void)
{
        
    return gmsh_yylineno;
}

/** Get the input stream.
 * 
 */
FILE *gmsh_yyget_in  (void)
{
        return gmsh_yyin;
}

/** Get the output stream.
 * 
 */
FILE *gmsh_yyget_out  (void)
{
        return gmsh_yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t gmsh_yyget_leng  (void)
{
        return gmsh_yyleng;
}

/** Get the current token.
 * 
 */

char *gmsh_yyget_text  (void)
{
        return gmsh_yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void gmsh_yyset_lineno (int  line_number )
{
    
    gmsh_yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see gmsh_yy_switch_to_buffer
 */
void gmsh_yyset_in (FILE *  in_str )
{
        gmsh_yyin = in_str ;
}

void gmsh_yyset_out (FILE *  out_str )
{
        gmsh_yyout = out_str ;
}

int gmsh_yyget_debug  (void)
{
        return gmsh_yy_flex_debug;
}

void gmsh_yyset_debug (int  bdebug )
{
        gmsh_yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from gmsh_yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    gmsh_yyin = stdin;
    gmsh_yyout = stdout;
#else
    gmsh_yyin = (FILE *) 0;
    gmsh_yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * gmsh_yylex_init()
     */
    return 0;
}

/* gmsh_yylex_destroy is for both reentrant and non-reentrant scanners. */
int gmsh_yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		gmsh_yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		gmsh_yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	gmsh_yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * gmsh_yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *gmsh_yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *gmsh_yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void gmsh_yyfree (void * ptr )
{
	free( (char *) ptr );	/* see gmsh_yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 235 "Gmsh.l"



#undef gmsh_yywrap

int gmsh_yywrap() {return 1;}

void skipcomments(void)
{
  int c;

  while (1) {
    while ((c = yyinput()) != '*'){
      if(feof(gmsh_yyin)){
	Msg::Error("End of file in commented region");
        return;
      }
    }
    if ((c = yyinput()) == '/')
      return;
    unput(c);
  }
}

void parsestring(char endchar)
{
  int c;
  char tmp[1024];
  
  // Note that we keep special characters (end-of-line \n, tabs \t,
  // etc.) "as is" in the output string: see yyinput() above
  int i = 0;
  while ((c = yyinput()) != endchar) {
    if(feof(gmsh_yyin)){
      Msg::Error("End of file in string");
      break;
    }
    else if(i >= (int)sizeof(tmp)-1){
      Msg::Error("String too long");
      break;
    }
    else{
      tmp[i++] = (char)c;
    }
  }
  tmp[i] = '\0';
  gmsh_yylval.c = strsave(tmp);
}

char *strsave(char *ptr)
{
  return((char*)strcpy((char*)malloc(strlen(ptr)+1),ptr));
}

void skipline()
{
  int c;
  while ((c = yyinput()) != '\n'){
    if(feof(gmsh_yyin)) return;
  }
}

void skip_until(const char *skip, const char *until)
{
  int i, nb_skip;
  int l, l_skip, l_until;
  char chars[256];

  nb_skip = 0;

  if(skip)
    l_skip = strlen(skip);
  else
    l_skip = 0;

  l_until = strlen(until);

  while(1){
    while (1){
      chars[0] = yyinput();
      if(feof(gmsh_yyin)){
	Msg::Error("Unexpected end of file");
	return;
      }
      if(chars[0] == until[0]) break;
      if(skip && chars[0] == skip[0]) break;
    }

    l = std::max(l_skip,l_until);
    if(l >= (int)sizeof(chars)){
      Msg::Error("Search pattern too long in skip_until");
      return;
    }
    for(i=1; i<l; i++){
      chars[i] = yyinput();
      if(feof(gmsh_yyin)){
	l = i;
	break;
      }
    }

    if(!strncmp(chars,until,l_until)){
      if(!nb_skip){
	return;
      }
      else{
	nb_skip--;
      }
    }
    else if(skip && !strncmp(chars,skip,l_skip)){
      nb_skip++;
    }
    else{
      for(i=1;i<l-1;i++){
	unput(chars[l-i]);
      }
    }

  }
}

void gmsh_yyflush() { YY_FLUSH_BUFFER; }

